package betterquesting.client.importers;

import betterquesting.api.questing.IQuestLine;
import betterquesting.api.questing.IQuestLineDatabase;
import betterquesting.api2.storage.DBEntry;
import betterquesting.api2.storage.SimpleDatabase;
import betterquesting.api2.utils.QuestLineSorter;
import betterquesting.questing.QuestLine;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import net.minecraft.nbt.NBTBase;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;

/* loaded from: betterquesting_client_importers.jar:betterquesting/client/importers/ImportedQuestLines.class */
public class ImportedQuestLines extends SimpleDatabase<IQuestLine> implements IQuestLineDatabase {
    private final List<Integer> lineOrder = new ArrayList();
    private final QuestLineSorter SORTER = new QuestLineSorter(this);

    public /* bridge */ /* synthetic */ NBTBase writeToNBT(NBTBase nBTBase, List list) {
        return writeToNBT((NBTTagList) nBTBase, (List<Integer>) list);
    }

    public int getOrderIndex(int lineID) {
        synchronized (this.lineOrder) {
            if (getValue(lineID) == null) {
                return -1;
            }
            if (!this.lineOrder.contains(Integer.valueOf(lineID))) {
                this.lineOrder.add(Integer.valueOf(lineID));
            }
            return this.lineOrder.indexOf(Integer.valueOf(lineID));
        }
    }

    public void setOrderIndex(int lineID, int index) {
        synchronized (this.lineOrder) {
            this.lineOrder.remove(Integer.valueOf(lineID));
            this.lineOrder.add(index, Integer.valueOf(lineID));
        }
    }

    public List<DBEntry<IQuestLine>> getSortedEntries() {
        List<DBEntry<IQuestLine>> ary = new ArrayList<>(getEntries());
        ary.sort(this.SORTER);
        return ary;
    }

    public NBTTagList writeToNBT(NBTTagList json, List<Integer> subset) {
        for (DBEntry<IQuestLine> entry : getEntries()) {
            if (subset == null || subset.contains(Integer.valueOf(entry.getID()))) {
                NBTTagCompound jObj = ((IQuestLine) entry.getValue()).writeToNBT(new NBTTagCompound(), (List) null);
                jObj.func_74768_a("lineID", entry.getID());
                jObj.func_74768_a("order", getOrderIndex(entry.getID()));
                json.func_74742_a(jObj);
            }
        }
        return json;
    }

    public void readFromNBT(NBTTagList json, boolean merge) {
        if (!merge) {
            reset();
        }
        List<IQuestLine> unassigned = new ArrayList<>();
        HashMap<Integer, Integer> orderMap = new HashMap<>();
        for (int i = 0; i < json.func_74745_c(); i++) {
            NBTTagCompound jql = json.func_150305_b(i);
            int id = jql.func_150297_b("lineID", 99) ? jql.func_74762_e("lineID") : -1;
            int order = jql.func_150297_b("order", 99) ? jql.func_74762_e("order") : -1;
            QuestLine line = new QuestLine();
            line.readFromNBT(jql, merge);
            if (id >= 0) {
                add(id, line);
            } else {
                unassigned.add(line);
            }
            if (order >= 0) {
                orderMap.put(Integer.valueOf(order), Integer.valueOf(id));
            }
        }
        for (IQuestLine q : unassigned) {
            add(nextID(), q);
        }
        List<Integer> orderKeys = new ArrayList<>(orderMap.keySet());
        Collections.sort(orderKeys);
        synchronized (this.lineOrder) {
            this.lineOrder.clear();
            Iterator<Integer> it = orderKeys.iterator();
            while (it.hasNext()) {
                int o = it.next().intValue();
                this.lineOrder.add(orderMap.get(Integer.valueOf(o)));
            }
        }
    }

    public void removeQuest(int questID) {
        for (DBEntry<IQuestLine> ql : getEntries()) {
            ((IQuestLine) ql.getValue()).removeID(questID);
        }
    }

    public IQuestLine createNew(int id) {
        QuestLine ql = new QuestLine();
        add(id, ql);
        return ql;
    }
}
